@@ -32,6 +32,16 @@ Dequeue.prototype.shift = function(){
   return n.data
 }
 
+Dequeue.prototype.last = function(){
+  if (this.head.prev === this.head) return
+  return this.head.prev.data
+}
+
+Dequeue.prototype.first = function(){
+  if (this.head.next === this.head) return
+  return this.head.next.data
+}
+
 Dequeue.prototype.empty = function(){
   if (this.length === 0 ) return
 
